AABB class

Constructors

AABB({required Vec2 position, required double width, required double height})

Properties

bottom double
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
getter/setter pair
left double
no setter
position Vec2
getter/setter pair
rect Rect
no setter
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
no setter
width double
getter/setter pair
x double
no setter
y double
no setter

Methods

copyWith({Vec2? position, double? width, double? height}) AABB
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited