Camera class

Constructors

Camera({double zoom = 1, double x = 0, double y = 0})

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
final
position Vec2
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shaking bool
getter/setter pair
zoom double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
shake({required WaitEvents wait, double time = 0.1, double amount = 2, bool slowlyHalt = false}) → void
start(Canvas canvas) → void
stop(Canvas canvas) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited