Circle class

Constructors

Circle({required Vec2 position, required double radius})

Properties

bottom double
no setter
hashCode int
The hash code for this object.
no setterinherited
left double
no setter
position Vec2
getter/setter pair
radius double
getter/setter pair
radSq double
no setter
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
no setter
x double
no setter
y double
no setter

Methods

copyWith({Vec2? position, double? radius}) Circle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited