CollisionDetector class abstract

Constructors

CollisionDetector()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

circleToCircle(Circle a, Circle b) bool
circleToRect(Circle circle, AABB rect) bool
lineToCircle(Line line, Circle circle) bool
lineToLine(Line a, Line b) bool
lineToRect(Line line, AABB rect) bool
pointToCircle(Vec2 p, Circle b) bool
pointToLine(Vec2 p, Line line, [double tolerance = 0.1]) bool
pointToRect(Vec2 p, AABB rect) bool
rectToRect(AABB a, AABB b) bool