AABB class

Inheritance

Constructors

AABB(Vec2 position, {required double width, required double height})

Properties

aabb AABB
no setteroverride
bottom double
no setter
circle Circle
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
getter/setter pair
left double
no setter
position Vec2
getter/setter pairinherited
rect Rect
no setter
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
no setter
width double
getter/setter pair
x double
no setterinherited
y double
no setterinherited

Methods

clone() AABB
override
deflate(double amount) → void
deflated(double amount) AABB
draw(Canvas canvas, Color color, [bool drawBoundingBox = false]) → void
override
inflate(double amount) → void
inflated(double amount) AABB
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited