Circle class

Inheritance

Constructors

Circle(Vec2 position, {required double radius})

Properties

aabb AABB
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
position Vec2
getter/setter pairinherited
radius double
getter/setter pair
radSq double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
no setterinherited
y double
no setterinherited

Methods

clone() Circle
override
draw(Canvas canvas, Color color, [bool drawBoundingBox = false]) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited