Line class

Inheritance

Constructors

Line(Vec2 p1, Vec2 p2)

Properties

aabb AABB
no setteroverride
bottom double
no setter
hashCode int
The hash code for this object.
no setterinherited
left double
no setter
p1 Vec2
no setter
p2 Vec2
getter/setter pair
position Vec2
getter/setter pairinherited
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
no setter
x double
no setterinherited
y double
no setterinherited

Methods

clone() Line
override
draw(Canvas canvas, Color color, [bool drawBoundingBox = false]) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited