Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
containsOrigin(
Shape shape) → bool -
containsOriginAABB(
AABB aabb) → bool -
containsOriginCircle(
Circle circle) → bool -
difference(
Shape a, Shape b) → Shape -
differenceAABB(
AABB a, AABB b) → AABB -
differenceAABBAndCircle(
AABB a, Circle b) → AABB -
differenceCircle(
Circle a, Circle b) → Circle -
differenceCircleAndAABB(
Circle a, AABB b) → AABB -
getPenetration(
Shape shape) → Vec2? -
getPenetrationAABB(
AABB aabb) → Vec2? -
getPenetrationCircle(
Circle circle) → Vec2?