Ray class

Constructors

Ray({required Vec2 origin, required Vec2 direction})

Properties

direction Vec2
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
origin Vec2
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

draw(Canvas canvas, Color color, double length, {bool drawArrowHead = true}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointAt(double distance) Vec2
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited