RaycastGridHit class

Constructors

RaycastGridHit({required int tx, required int ty, required double distance, required Vec2 point, required int normalX, required int normalY})

Properties

distance double
final
hashCode int
The hash code for this object.
no setterinherited
normalX int
final
normalY int
final
point Vec2
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tx int
final
ty int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited