RaycastHit<T> class

Constructors

RaycastHit({required T object, required Vec2 point, required Vec2 normal, required double distance})

Properties

distance double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
normal Vec2
getter/setter pair
object ↔ T
getter/setter pair
point Vec2
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited