Raycaster class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

raycastAABB(Ray ray, AABB aabb) RaycastHit<AABB>?
raycastCircle(Ray ray, Circle circle) RaycastHit<Circle>?
raycastGrid(Ray ray, {required int cellSize, required double maxDistance, required bool isSolid(int tx, int ty)}) RaycastGridHit?
raycastLine(Ray ray, Line line) RaycastHit<Line>?
raycastShape(Ray ray, Shape shape) RaycastHit<Shape>?
raycastSpatial<T>(Ray ray, SpatialHash<T> world, Shape shape(T)) RaycastHit<T>?