RigidBody class

Constructors

RigidBody({required Shape shape, Vec2? velocity, double mass = 1.0, double elasticity = 0.5, bool isStatic = false})

Properties

elasticity double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
invMass double
no setter
isStatic bool
getter/setter pair
mass double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape Shape
getter/setter pair
velocity Vec2
getter/setter pair

Methods

applyImpulse(Vec2 impulse) → void
copyWith({Shape? shape, Vec2? velocity, double? mass, double? elasticity, bool? isStatic}) RigidBody
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(double deltaTime) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited