Shape class abstract

Implementers

Constructors

Shape(Vec2 position)

Properties

aabb AABB
no setter
hashCode int
The hash code for this object.
no setterinherited
position Vec2
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
no setter
y double
no setter

Methods

clone() Shape
draw(Canvas canvas, Color color, [bool drawBoundingBox = true]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

paint Paint
final