SpatialHash<T> class

Constructors

SpatialHash({required double cellSize})

Properties

cellCount int
no setter
cellSize double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
insert(T obj, AABB bounds) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(AABB bounds) List<T>
remove(T obj, AABB bounds) → void
toString() String
A string representation of this object.
inherited
update(T obj, AABB oldBounds, AABB newBounds) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited