Spring1D class

Constructors

Spring1D({required double initialValue, double stiffness = 180.0, double damping = 12.0})
Spring1D.critical({required double initialValue, double stiffness = 180.0})

Properties

damping double
Larger = less oscillation.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stiffness double
Larger = reaches target faster.
final
value double
getter/setter pair
velocity double
getter/setter pair

Methods

isSettled(double target, [double threshold = 0.001]) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
snap(double newValue) → void
toString() String
A string representation of this object.
inherited
update(double dt, double target) double

Operators

operator ==(Object other) bool
The equality operator.
inherited