Spring2D class
Constructors
Properties
- damping → double
-
Larger = less oscillation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pos ↔ Vec2
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stiffness → double
-
Larger = reaches target faster.
final
- velocity ↔ Vec2
-
getter/setter pair
Methods
-
isSettled(
Vec2 target, [double threshold = 0.001]) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
snap(
Vec2 newPos) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
double dt, Vec2 target) → Vec2
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited