Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
expand(
Shape moving, Shape target) → Shape -
expandAABB(
AABB moving, AABB target) → AABB -
expandAABBAndCircle(
AABB moving, Circle target) → AABB -
expandCircle(
Circle moving, Circle target) → Circle -
expandCircleAndAABB(
Circle moving, AABB target) → AABB