AnimationData<T extends Object> class

Constructors

AnimationData({required T name, required List<TexArea> frames, required double speed})

Properties

frames List<TexArea>
final
hashCode int
The hash code for this object.
no setterinherited
name → T
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited