CanvasText class

Constructors

CanvasText({String text = '', TextStyle style = const TextStyle(color: Colors.white), TextDirection direction = TextDirection.ltr, TextAlign align = TextAlign.left, Offset origin = Offset.zero})

Properties

hashCode int
The hash code for this object.
no setterinherited
origin Offset
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
no setter
style TextStyle
getter/setter pair
text String
getter/setter pair

Methods

draw(Canvas canvas, Vec2 position) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited