SpriteBatch class

Properties

frames Map<String, List<TexArea>>
no setter
hashCode int
The hash code for this object.
no setterinherited
image Image
no setter
pages List<Image>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textures Map<String, TexArea>
no setter

Methods

dispose() → void
draw(Canvas canvas, List<Sprite> sprites, {BlendMode blendMode = BlendMode.modulate, AABB? cullArea}) → void
getAnimation<T extends Object>(T name, {required double speed}) AnimationData<T>
getEnum({String name = "Tex"}) String
For development and debugging purposes
getTexture<T extends Object>(T name) TexArea
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

paint Paint
final

Static Methods

custom({required List<Image> pages, required Map<String, TexArea> textures, required Map<String, List<TexArea>> frames, bool flippable = false, bool maskable = false, bool disposeOriginal = false}) Future<SpriteBatch>
fromGdxPacker(String path, {bool flippable = false, bool maskable = false}) Future<SpriteBatch>
transformSheetImage(Image image, {required bool flippable, required bool maskable, bool disposeOriginal = false}) Future<Image>