TexArea class

Constructors

TexArea({required Rect rect, int pageIndex = 0})
const

Properties

bottom double
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
no setter
left double
no setter
pageIndex int
final
rect Rect
final
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
no setter
width double
no setter

Methods

copy() TexArea
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited