TileMap class

Constructors

TileMap({required List<Rect> tileAreas, required Image image, double tileScale = 1.0})

Properties

hashCode int
The hash code for this object.
no setterinherited
image Image
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tileAreas List<Rect>
final
tileScale double
getter/setter pair

Methods

drawGrid(Canvas canvas, Grid<int> grid, {Vec2? position, AABB? cullArea}) → void
drawGrids(Canvas canvas, List<Grid<int>> grids, {Vec2? position, AABB? cullArea}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

paint Paint
final