onSignal property
If you return true it will rebuild the widget If you return false it won't rebuild the widget, and it will stop listening to the signal If you return null it won't rebuild the widget, but it will still listen to the signal
Implementation
final SubscriptionCallback<T>? onSignal;